@@ -11,8 +11,8 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '2.4'
-Build = '8'
+Version = '2.5'
+Build = '1'
 
 import sys
 import os
@@ -34,12 +34,12 @@ from clevenManageCapturedUI import *
 
 pathMain             = '/opt/cleven'                        # main path for the application
 pathStorage          = '/home/user/.cleven'                 # storage path for the application
-pathDrivers          = '%s/compat-wireless' % pathMain
 pathReaver           = '/home/user/.reaver'                 # storage path for reaver
 helperScript         = 'clevenHelper.sh'
 folderKeys           = 'keys'
 folderDictionaries   = 'dictionaries'
 folderCapturedData   = 'capturedData'
+
 reaverBinary         = 'reaver'
 reaverDatabase       = 'reaver.db'
 washBinary           = 'wash'
@@ -374,8 +374,10 @@ class clevenConfigureDrivers(QtGui.QDialog):
 
        global kernelVersion
        kernelVersion = os.popen('uname -r').read().strip('\n').strip('')
-       print kernelVersion
-       
+       print "Version of Kernel found: ", kernelVersion
+       global driversVersion
+       driversVersion = '-v1'
+              
        if kernelVersion == '2.6.28.10power46-wl1':
           pass
        elif kernelVersion == '2.6.28.10-power47':
@@ -384,10 +386,14 @@ class clevenConfigureDrivers(QtGui.QDialog):
           pass
        elif kernelVersion == '2.6.28.10-power49':
           pass
+       elif kernelVersion == '2.6.28.10-power50':
+          driversVersion = '-v2'
        else: 
           message = 'WARNING: The system did not find a known compatible kernel version for the injection drivers.\n\nThe application might not work properly..'
           showMessage(message)
-    
+
+       print "Version of drivers chosen: ", driversVersion
+          
     def getDriversState(self):
        '''Check the state of the Drivers (Stock/Bleeding)'''
        
@@ -447,7 +453,7 @@ class clevenConfigureDrivers(QtGui.QDialog):
        message ='Loading the injection drivers..'
        showQuickMessage(message)
        
-       os.system('sudo %s/load.sh' % pathDrivers)
+       os.system('sudo %s/load.sh %s' % (pathMain,driversVersion))
        self.getDriversState()
        self.getInterfaceState()
        self.getMAC()
@@ -458,7 +464,7 @@ class clevenConfigureDrivers(QtGui.QDialog):
        message ='Unloading the injection drivers..'
        showQuickMessage(message)
 
-       os.system('sudo %s/unload.sh' % pathDrivers)
+       os.system('sudo %s/unload.sh' % pathMain)
        self.getInterfaceState()
        self.getMAC()
        self.getDriversState()
